#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-FLdeVQtmcKt4QBRsU2jImE
key:                  storable-complex-0.2.3.0-FLdeVQtmcKt4QBRsU2jImE
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  4da0799b74d73ce77e7112e611148391
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-FLdeVQtmcKt4QBRsU2jImE
depends:
    base-4.18.2.1 base-orphans-0.9.4-CDw63M2o0vVHJ7sm56eOQt

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

